==> haskell-prettyprinter-compat-ansi-wl-pprint-1.0.2-81-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-compat-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prettyprinter-compat-ansi-wl-pprint
version:              1.0.2
visibility:           public
id:
    prettyprinter-compat-ansi-wl-pprint-1.0.2-4ticcl4WE6uHRcoAW2mdlR

key:
    prettyprinter-compat-ansi-wl-pprint-1.0.2-4ticcl4WE6uHRcoAW2mdlR

license:              BSD-2-Clause
maintainer:           David Luposchainsky <dluposchainsky at google>
author:               David Luposchainsky
homepage:             http://github.com/quchen/prettyprinter
synopsis:
    Drop-in compatibility package to migrate from »ansi-wl-pprint« to »prettyprinter«.

description:          See README.md
category:             User Interfaces, Text
abi:                  7083cf7d82ed8824d8e6b5a72ef45249
exposed:              True
exposed-modules:      Text.PrettyPrint.ANSI.Leijen
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/prettyprinter-compat-ansi-wl-pprint-1.0.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/prettyprinter-compat-ansi-wl-pprint-1.0.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/prettyprinter-compat-ansi-wl-pprint-1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter-compat-ansi-wl-pprint
hs-libraries:
    HSprettyprinter-compat-ansi-wl-pprint-1.0.2-4ticcl4WE6uHRcoAW2mdlR

depends:
    base-4.17.2.1 prettyprinter-1.7.1-3fr7GBE89dlFqu04SpDoXe
    prettyprinter-ansi-terminal-1.1.3-JP0v4dxjmjhCZh2HNoBnwd text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-compat-ansi-wl-pprint/html/prettyprinter-compat-ansi-wl-pprint.haddock

haddock-html:
    /usr/share/doc/haskell-prettyprinter-compat-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyprinter-compat-ansi-wl-pprint-1.0.2-82-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-compat-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prettyprinter-compat-ansi-wl-pprint
version:              1.0.2
visibility:           public
id:
    prettyprinter-compat-ansi-wl-pprint-1.0.2-3VqgHtTfvvEEicQfUeNGEz

key:
    prettyprinter-compat-ansi-wl-pprint-1.0.2-3VqgHtTfvvEEicQfUeNGEz

license:              BSD-2-Clause
maintainer:           David Luposchainsky <dluposchainsky at google>
author:               David Luposchainsky
homepage:             http://github.com/quchen/prettyprinter
synopsis:
    Drop-in compatibility package to migrate from »ansi-wl-pprint« to »prettyprinter«.

description:          See README.md
category:             User Interfaces, Text
abi:                  caf108ff2a0558b77634d930f2641e22
exposed:              True
exposed-modules:      Text.PrettyPrint.ANSI.Leijen
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/prettyprinter-compat-ansi-wl-pprint-1.0.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/prettyprinter-compat-ansi-wl-pprint-1.0.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/prettyprinter-compat-ansi-wl-pprint-1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter-compat-ansi-wl-pprint
hs-libraries:
    HSprettyprinter-compat-ansi-wl-pprint-1.0.2-3VqgHtTfvvEEicQfUeNGEz

depends:
    base-4.17.2.1 prettyprinter-1.7.1-JBUxpob9pPVLD8OaO2d4B1
    prettyprinter-ansi-terminal-1.1.3-DPjP9lcwT5a9DsbOdvTpk3 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-compat-ansi-wl-pprint/html/prettyprinter-compat-ansi-wl-pprint.haddock

haddock-html:
    /usr/share/doc/haskell-prettyprinter-compat-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
